==> blazy_video_embed_field-8.x-2.0-rc1.tar.gz: blazy_video_embed_field/src/Plugin/Field/FieldFormatter/BlazyVideoEmbedFieldPlayerFormatter.php <==
<?php

namespace Drupal\blazy_video_embed_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\blazy\Plugin\Field\FieldFormatter\BlazyFormatterTrait;
use Drupal\blazy\BlazyFormatterManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Formatter for 'Blazy Video' to get video_embed_field videos.
 *
 * This is a gap formatter to support video_embed_field media types with
 * blazy 2.x that no longer supports video embed field.
 * The blazy 2.x supports core media's oembed (core 8.6+).
 * For converting video_embed_field to core media oembed, the following patch
 * provides a drush command to convert:
 * - https://www.drupal.org/project/video_embed_field/issues/2997799
 *
 * @FieldFormatter(
 *   id = "blazy_vef_default",
 *   label = @Translation("Blazy Video Embed Field"),
 *   description = @Translation("Lazy load the video embed field."),
 *   field_types = {
 *     "video_embed_field"
 *   }
 * )
 */
class BlazyVideoEmbedFieldPlayerFormatter extends BlazyVideoEmbedFieldBase implements ContainerFactoryPluginInterface {

  use BlazyFormatterTrait;
  use BlazyVideoEmbedFieldTrait;

  /**
   * Constructs a BlazyFormatter object.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, BlazyFormatterManager $blazy_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->blazyManager = $blazy_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('blazy.formatter.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $build = [];

    // Early opt-out if the field is empty.
    if ($items->isEmpty()) {
      return $build;
    }

    // Collects specific settings to this formatter.
    $settings              = $this->buildSettings();
    $settings['blazy']     = TRUE;
    $settings['namespace'] = $settings['item_id'] = $settings['lazy'] = 'blazy';

    // Build the settings.
    $build = ['settings' => $settings];

    // Modifies settings.
    $this->blazyManager->buildSettings($build, $items);

    // Fecthes URI from the first item to build dimensions once.
    $this->buildVideo($build['settings'], $items[0]->value);

    // Build the elements.
    $this->buildElements($build, $items);

    // Updates settings.
    $settings = $build['settings'];
    unset($build['settings']);

    // Supports Blazy multi-breakpoint images if provided.
    if (!empty($settings['uri'])) {
      $this->blazyManager->isBlazy($settings, $build[0]['#build']);
    }

    $build['#blazy'] = $settings;
    $build['#attached'] = $this->blazyManager->attach($settings);
    return $build;
  }

  /**
   * Build the blazy elements.
   */
  public function buildElements(array &$build, $items) {
    $settings = $build['settings'];

    foreach ($items as $delta => $item) {
      $settings['input_url'] = trim(strip_tags($item->value));

      $settings['delta'] = $delta;
      if (empty($settings['input_url'])) {
        continue;
      }

      $this->buildVideo($settings);

      $box = ['item' => $item, 'settings' => $settings];

      // Image with responsive image, lazyLoad, and lightbox supports.
      $build[$delta] = $this->blazyManager->getImage($box);
      unset($box);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getScopedFormElements() {
    return [
      'fieldable_form' => TRUE,
      'multimedia'     => TRUE,
      'view_mode'      => $this->viewMode,
    ] + parent::getScopedFormElements();
  }

}

==> blazy_video_embed_field-8.x-2.1.tar.gz: blazy_video_embed_field/src/Plugin/Field/FieldFormatter/BlazyVideoEmbedFieldPlayerFormatter.php <==
<?php

namespace Drupal\blazy_video_embed_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Formatter for 'Blazy Video' to get video_embed_field videos.
 *
 * This is a gap formatter to support video_embed_field media types with
 * blazy 2.x that no longer supports video embed field.
 * The blazy 2.x supports core media's oembed (core 8.6+).
 * For converting video_embed_field to core media oembed, the following patch
 * provides a drush command to convert:
 * - https://www.drupal.org/project/video_embed_field/issues/2997799
 *
 * @FieldFormatter(
 *   id = "blazy_vef_default",
 *   label = @Translation("Blazy Video Embed Field"),
 *   description = @Translation("Lazy load the video embed field."),
 *   field_types = {
 *     "video_embed_field"
 *   }
 * )
 */
class BlazyVideoEmbedFieldPlayerFormatter extends BlazyVideoEmbedFieldBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $build = [];

    // Early opt-out if the field is empty.
    if ($items->isEmpty()) {
      return $build;
    }

    // Collects specific settings to this formatter.
    $settings              = $this->buildSettings();
    $settings['blazy']     = TRUE;
    $settings['namespace'] = $settings['item_id'] = $settings['lazy'] = 'blazy';

    // Build the settings.
    $build = ['settings' => $settings];

    // Modifies settings.
    $this->blazyManager()->buildSettings($build, $items);

    // Fetches URI from the first item to build dimensions once.
    $this->buildVideo($build['settings'], $items->first()->value);

    // Build the elements.
    $this->buildElements($build, $items);
    if (empty($build[0]['#build'])) {
      // Skip if no items were built.
      return $build;
    }

    // Updates settings.
    $settings = $build['settings'];
    unset($build['settings']);

    // Supports Blazy multi-breakpoint images if provided.
    if (!empty($settings['uri'])) {
      // The isBlazy() alters the $settings.
      $this->blazyManager()->isBlazy($settings, $build[0]['#build']);
    }

    $build['#blazy'] = $settings;
    $build['#attached'] = $this->blazyManager()->attach($settings);
    return $build;
  }

  /**
   * Build the blazy elements.
   */
  public function buildElements(array &$build, $items) {
    foreach ($items as $delta => $item) {
      if (empty($item->value)) {
        continue;
      }

      $settings = !empty($build['settings']) ? $build['settings'] : [];
      $settings['delta'] = $delta;
      $settings['input_url'] = trim(strip_tags($item->value));

      if (empty($settings['input_url'])) {
        continue;
      }

      $this->buildVideo($settings);

      $blazy_build = ['item' => $item, 'settings' => $settings];

      // Image with responsive image, lazyLoad, and lightbox supports.
      $build[$delta] = $this->blazyManager()->getBlazy($blazy_build);
      unset($blazy_build);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getScopedFormElements() {
    return [
      'fieldable_form' => TRUE,
      'multimedia'     => TRUE,
      'view_mode'      => $this->viewMode,
    ] + parent::getScopedFormElements();
  }

}
